@@ -8,6 +8,15 @@ from xdev import util
 import time
 
 
+def _stop_rich_live_contexts():
+    # Stop any rich live context.
+    if 'rich' in sys.modules:
+        import rich
+        console = rich.get_console()
+        if console._live is not None:
+            console._live.__exit__(None, None, None)
+
+
 def embed(parent_locals=None, parent_globals=None, exec_lines=None,
           remove_pyqt_hook=True, n=0):
     """
@@ -19,10 +28,8 @@ def embed(parent_locals=None, parent_globals=None, exec_lines=None,
         program if embed is called in a loop. Specifically if you want to quit
         and not embed again, then set qqq=1 before exiting the embed session.
     """
-    from xdev._ipython_ext import embed2
-    # import IPython
-    import xdev  # NOQA
-    import xdev as xd  # NOQA
+    if 1:
+        _stop_rich_live_contexts()
     import os
 
     if parent_globals is None:
@@ -60,6 +67,11 @@ def embed(parent_locals=None, parent_globals=None, exec_lines=None,
         import logging
         logging.getLogger('parso').setLevel(logging.INFO)
 
+    from xdev._ipython_ext import embed2
+    # import IPython
+    import xdev  # NOQA
+    import xdev as xd  # NOQA
+
     #from IPython.config.loader import Config
     # cfg = Config()
     #config_dict = {}
@@ -148,18 +160,22 @@ class EmbedOnException(object):
     """
     Context manager which embeds in ipython if an exception is thrown
     """
-    def __init__(self):
-        pass
+    def __init__(self, before_embed=None):
+        self.before_embed = before_embed
 
     def __enter__(self):
         return self
 
-    def __call__(self):
+    def __call__(self, before_embed=None):
+        # This is quirky behavior, but probably fine
+        self.before_embed = before_embed
         return self
 
     def __exit__(__self, __type, __value, __trace):
         if __trace is not None:
             print('!!! EMBED ON EXCEPTION !!!')
+            if __self.before_embed is not None:
+                __self.before_embed()
             print('[util_dbg] %r in context manager!: %s ' % (__type, str(__value)))
             import traceback
             traceback.print_exception(__type, __value, __trace)
