@@ -110,7 +110,16 @@ def byte_str(num, unit='auto', precision=2):
 
 def set_overlaps(set1, set2, s1='s1', s2='s2'):
     """
-    return info about set overlaps
+    Return sizes about set overlaps
+
+    Args:
+        set1 (Iterable):
+        set2 (Iterable):
+        s1 (str): name for set1
+        s2 (str): name for set2
+
+    Returns:
+        Dict[str, int]: sizes of sets intersections unions and differences
 
     Notes:
         This function needs a rename. Possible candidates brainstorm:
@@ -298,21 +307,20 @@ def difftext(text1, text2, context_lines=0, ignore_whitespace=False,
 
 def tree_repr(cwd=None, max_files=100, dirblocklist=None, show_nfiles='auto',
               return_text=False, return_tree=False, pathstyle='name',
-              with_type=False, colors=not ub.NO_COLOR):
+              max_depth=None, with_type=False, colors=not ub.NO_COLOR):
     """
     Filesystem tree representation
 
     Like the unix util tree, but allow writing numbers of files per directory
     when given -d option
 
-    cwd = '/data/public/Aerial/US_ALASKA_MML_SEALION'
-
     Args:
-        cwd : directory to print
-        max_files : maximum files to print before supressing a directory
+        cwd (None | str | PathLike) : directory to print
+        max_files (int | None) : maximum files to print before supressing a directory
         pathstyle (str): can be rel, name, or abs
         return_tree (bool): if True return the tree
         return_text (bool): if True return the text
+        maxdepth (int | None): maximum depth to descend
         colors (bool): if True use rich
 
     SeeAlso:
@@ -370,6 +378,9 @@ def tree_repr(cwd=None, max_files=100, dirblocklist=None, show_nfiles='auto',
             if colors:
                 scolor = '[reset]'
                 tcolor = '[/reset]'
+                if os.access(p, os.X_OK):
+                    scolor = '[green]'
+                    tcolor = '[/green]'
             types.append('F')
         if isdir:
             if colors:
@@ -390,7 +401,13 @@ def tree_repr(cwd=None, max_files=100, dirblocklist=None, show_nfiles='auto',
             return pathrep
 
     # TODO: rectify with "find"
+    start_depth = str(cwd).count(os.path.sep)
     for root, dnames, fnames in os.walk(cwd):
+        curr_depth = str(root).count(os.path.sep)
+
+        if max_depth is not None:
+            if (curr_depth - start_depth):
+                del dnames[:]
 
         if dirblocklist is not None:
             dnames[:] = [
